import unittest
from injecta.testing.servicesTester import testServices
from injecta.config.YamlConfigReader import YamlConfigReader
from injecta.package.pathResolver import resolvePath
from typing import List
from pyfony.kernel.BaseKernel import BaseKernel
from pyfonybundles.Bundle import Bundle
from loggerbundle.LoggerBundle import LoggerBundle
from azureloggerbundle.AzureLoggerBundle import AzureLoggerBundle

class AzureLoggerBundleTest(unittest.TestCase):

    def test_init(self):
        class Kernel(BaseKernel):

            def _registerBundles(self) -> List[Bundle]:
                return [
                    LoggerBundle(),
                    AzureLoggerBundle(),
                ]

        kernel = Kernel(
            'test',
            resolvePath('azureloggerbundle') + '/_config',
            YamlConfigReader()
        )

        container = kernel.initContainer()

        testServices(container)

if __name__ == '__main__':
    unittest.main()



# pylint: disable = abstract-method
from opencensus.ext.azure.log_exporter import AzureLogHandler, Envelope, Message  # pylint: disable = unused-import
from loggerbundle.extra.ExtraKeysResolver import ExtraKeysResolver

class AzureLogWithExtraHandler(AzureLogHandler):

    def log_record_to_envelope(self, record):
        envelope = super().log_record_to_envelope(record) # type: Envelope

        message = envelope.data.baseData # type: Message

        recordDict = record.__dict__
        extraKeys = ExtraKeysResolver.getExtraKeys(record)

        message.properties['loggerName'] = record.name

        for k in extraKeys:
            if k != 'message':
                message.properties['extra_{}'.format(k)] = str(recordDict[k])

        return envelope



from azureloggerbundle.appInsights.AzureLogWithExtraHandler import AzureLogWithExtraHandler
from loggerbundle.handler.HandlerFactoryInterface import HandlerFactoryInterface

class AppInsightsLogHandlerFactory(HandlerFactoryInterface):

    def __init__(
        self,
        instrumentationKey: str,
    ):
        self.__instrumentationKey = instrumentationKey

    def create(self):
        return AzureLogWithExtraHandler(
            connection_string='InstrumentationKey={}'.format(self.__instrumentationKey)
        )



# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['azureloggerbundle']

package_data = \
{'': ['*'], 'azureloggerbundle': ['_config/*', 'appInsights/*']}

install_requires = \
['logger-bundle>=0.5.0,<0.6.0',
 'opencensus-ext-azure>=1.0.0,<1.1.0',
 'opencensus>=0.7.0,<0.8.0']

setup_kwargs = {
    'name': 'azure-logger-bundle',
    'version': '0.1.2',
    'description': 'Azure Logger bundle for the Pyfony framework',
    'long_description': 'Azure Logger bundle for the Pyfony Framework\n',
    'author': 'Jiri Koutny',
    'author_email': 'jiri.koutny@datasentics.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/bricksflow/azure-logger-bundle',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7.3,<3.8.0',
}


setup(**setup_kwargs)
